@@ -40,7 +40,7 @@ import pyflakes.messages
 import pyflakes.reporter
 
 
-__version__ = "1.7.3"
+__version__ = "1.7.5"
 
 
 _LOGGER = logging.getLogger("autoflake")
@@ -924,7 +924,7 @@ def _fix_file(
 
     filtered_source = fix_code(
         source,
-        additional_imports=args.get("imports", "").split(","),
+        additional_imports=(args["imports"].split(",") if "imports" in args else None),
         expand_star_imports=args["expand_star_imports"],
         remove_all_unused_imports=args["remove_all_unused_imports"],
         remove_duplicate_keys=args["remove_duplicate_keys"],
@@ -1453,7 +1453,11 @@ def _main(argv, standard_out, standard_error, standard_input=None) -> int:
         args["exclude"] = set()
 
     if args["jobs"] < 1:
-        args["jobs"] = os.cpu_count() or 1
+        worker_count = os.cpu_count()
+        if sys.platform == "win32":
+            # Work around https://bugs.python.org/issue26903
+            worker_count = min(worker_count, 60)
+        args["jobs"] = worker_count or 1
 
     filenames = list(set(args["files"]))
 
